@@ -528,6 +528,42 @@ gdm_common_setup_background_color (gchar *bg_color)
 		}
 }
 
+void
+gdm_common_set_root_background (GdkPixbuf *pb)
+{
+	GdkPixmap *pm;
+	gint width, height;
+
+	g_return_if_fail (pb != NULL);
+
+	gdk_drawable_get_size (gdk_get_default_root_window (), &width, &height);
+	pm = gdk_pixmap_new (gdk_get_default_root_window (), 
+			width, height, -1);
+
+
+	/* paranoia */
+	if (pm == NULL)
+		return;
+
+	gdk_draw_pixbuf (pm, NULL, pb, 0, 0, 0, 0, -1, -1, 
+			GDK_RGB_DITHER_MAX, 0, 0);
+
+	gdk_error_trap_push ();
+
+	gdk_window_set_back_pixmap (gdk_get_default_root_window (),
+				    pm,
+				    FALSE /* parent_relative */);
+
+	g_object_unref (G_OBJECT (pm));
+
+	gdk_window_clear (gdk_get_default_root_window ());
+
+	gdk_flush ();
+	gdk_error_trap_pop ();
+}
+
+
+
 gchar *
 gdm_common_get_welcomemsg (void)
 {
