@@ -23,7 +23,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <signal.h>
-#include <syslog.h>
+#include <errno.h>
 
 #if HAVE_PAM
 #include <security/pam_appl.h>
@@ -37,7 +37,9 @@
 #include <gdk/gdkkeysyms.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 
-#include "vicious.h"
+#include "gdm-common.h"
+#include "gdm-socket-protocol.h"
+#include "gdm-daemon-config-keys.h"
 
 #include "gdm.h"
 #include "gdmwm.h"
@@ -45,6 +47,7 @@
 #include "gdmcommon.h"
 #include "gdmconfig.h"
 #include "gdmsession.h"
+#include "gdmlanguages.h"
 
 #include "greeter.h"
 #include "greeter_configuration.h"
@@ -57,7 +60,6 @@
 #include "greeter_item_capslock.h"
 #include "greeter_item_timed.h"
 #include "greeter_events.h"
-#include "greeter_action_language.h"
 #include "greeter_session.h"
 #include "greeter_system.h"
 
@@ -77,6 +79,7 @@ gboolean GdmConfiguratorFound  = FALSE;
 
 /* FIXME: hack */
 GreeterItemInfo *welcome_string_info = NULL;
+GreeterItemInfo *root = NULL;
 
 extern gboolean session_dir_whacked_out;
 extern gboolean require_quarter;
@@ -95,15 +98,22 @@ greeter_ignore_buttons (gboolean val)
    ignore_buttons = val;
 }
 
-/* If in random theme mode then grab a random theme from those selected */
+static char *get_theme_file (const char *in, char **theme_dir);
+
+/* If in random theme mode then grab a random theme from those selected.
+ * If a theme doesn't exist, try  the rest of the list from the randomly chosen
+ * position for one that does.
+ */
 static char *
 get_random_theme ()
 {
     char **vec;
-	char *themes_list;
-	char *theme;
+    char *themes_list;
+    char *theme = NULL;
+    char *dir;
     int size;
-	int i;
+    int chosen;
+    int i;
 
     themes_list = gdm_config_get_string (GDM_KEY_GRAPHICAL_THEMES);
 
@@ -118,9 +128,26 @@ get_random_theme ()
     for (size = 0; vec[size] != NULL; size++) {}
 
 	/* Get Random Theme from list */
-	srand (time (NULL));
-	i = rand () % size;
-	theme = g_strdup (vec[i]);
+	srand ( time(NULL) );
+	chosen = rand() % size;
+
+	/* Find a theme that exists */
+	for (i = 0; i < size; i++) {
+		int j;
+		char *file;
+
+		j = (i + chosen >= size) ? i+chosen-size : i+chosen;
+		file = get_theme_file( vec[j], &dir );
+
+		g_free(file);
+		if (g_file_test(dir, G_FILE_TEST_IS_DIR)) {
+		    g_free(dir);
+			theme = g_strdup (vec[j]);
+			break;
+		}
+	    g_free(dir);
+	}
+
     g_strfreev (vec);
 
     return theme;
@@ -164,6 +191,32 @@ greeter_ctrl_handler (GIOChannel *source,
     return TRUE;
 }
 
+static GtkWidget *
+hig_dialog_new (GtkWindow      *parent,
+		GtkDialogFlags flags,
+		GtkMessageType type,
+		GtkButtonsType buttons,
+		const gchar    *primary_message,
+		const gchar    *secondary_message)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
+		                         GTK_DIALOG_DESTROY_WITH_PARENT,
+		                         type,
+		                         buttons,
+		                         "%s", primary_message);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		                                  "%s", secondary_message);
+
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+
+  	return dialog;
+}
+
 static void
 process_operation (guchar       op_code,
 		   const gchar *args)
@@ -173,8 +226,6 @@ process_operation (guchar       op_code,
     char *session;
     GreeterItemInfo *conversation_info;
     static GnomeCanvasItem *disabled_cover = NULL;
-    gchar *language;
-    gchar *selected_user = NULL;
     gint lookup_status = SESSION_LOOKUP_SUCCESS;
     gchar *firstmsg = NULL;
     gchar *secondmsg = NULL;
@@ -254,12 +305,12 @@ process_operation (guchar       op_code,
 	gdm_wm_focus_new_windows (TRUE);
 
 	tmp = ve_locale_to_utf8 (args);
-	dlg = ve_hig_dialog_new (NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_ERROR,
-				 GTK_BUTTONS_OK,
-				 tmp,
-				 "");
+	dlg = hig_dialog_new (NULL /* parent */,
+                              GTK_DIALOG_MODAL /* flags */,
+                              GTK_MESSAGE_ERROR,
+                              GTK_BUTTONS_OK,
+                              tmp,
+                              "");
 	g_free (tmp);
 
 	gdm_wm_center_window (GTK_WINDOW (dlg));
@@ -341,13 +392,7 @@ process_operation (guchar       op_code,
 	break;
 
     case GDM_LANG:
-	language = greeter_language_get_language (args);
-	if (greeter_language_get_save_language () == GTK_RESPONSE_CANCEL)
-	    printf ("%c%s\n", STX, GDM_RESPONSE_CANCEL);
-	else
-	    printf ("%c%s\n", STX, language);
-	fflush (stdout);
-	g_free (language);
+	gdm_lang_op_lang (args);
 	break;
 
     case GDM_SSESS:
@@ -360,12 +405,15 @@ process_operation (guchar       op_code,
 	break;
 
     case GDM_SLANG:
-	if (greeter_language_get_save_language () == GTK_RESPONSE_YES)
-	    printf ("%cY\n", STX);
-	else
-	    printf ("%c\n", STX);
-	fflush (stdout);
+	gdm_lang_op_slang (args);
+	break;
 
+    case GDM_SETLANG:
+	gdm_lang_op_setlang (args);
+	break;
+
+    case GDM_ALWAYS_RESTART:
+	gdm_lang_op_always_restart (args);
 	break;
 
     case GDM_RESET:
@@ -405,15 +453,15 @@ process_operation (guchar       op_code,
 		/* we should be now fine for focusing new windows */
 		gdm_wm_focus_new_windows (TRUE);
 
-		dlg = ve_hig_dialog_new (NULL /* parent */,
-					 GTK_DIALOG_MODAL /* flags */,
-					 GTK_MESSAGE_INFO,
-					 GTK_BUTTONS_OK,
-					 /* translators:  This is a nice and evil eggie text, translate
-					  * to your favourite currency */
-					 _("Please insert 25 cents "
-					   "to log in."),
-					 "");
+		dlg = hig_dialog_new (NULL /* parent */,
+                                      GTK_DIALOG_MODAL /* flags */,
+                                      GTK_MESSAGE_INFO,
+                                      GTK_BUTTONS_OK,
+                                      /* translators:  This is a nice and evil eggie text, translate
+                                       * to your favourite currency */
+                                      _("Please insert 25 cents "
+                                        "to log in."),
+                                      "");
 		gdm_wm_center_window (GTK_WINDOW (dlg));
 
 		gdm_wm_no_login_focus_push ();
@@ -426,6 +474,18 @@ process_operation (guchar       op_code,
 
 	gdk_flush ();
 
+	if (greeter_show_only_background (root)) {
+		GdkPixbuf *background;
+		int width, height;
+
+		gtk_window_get_size (GTK_WINDOW (window), &width, &height);
+		background = gdk_pixbuf_get_from_drawable (NULL, gtk_widget_get_root_window(window), NULL, 0, 0, 0, 0 ,width, height);
+		if (background) {
+			gdm_common_set_root_background (background);
+			g_object_unref (background);
+		}
+	}
+
 	printf ("%c\n", STX);
 	fflush (stdout);
 
@@ -532,7 +592,7 @@ key_press_event (GtkWidget *widget, GdkEventKey *key, gpointer data)
 {
   if (DOING_GDM_DEVELOPMENT && (key->keyval == GDK_Escape))
     {
-      gtk_main_quit ();
+      process_operation (GDM_QUIT, NULL);
       
       return TRUE;
     }
@@ -577,6 +637,13 @@ greeter_cancel_handler (GreeterItemInfo *info,
      }
 }
 
+static void
+greeter_language_handler (GreeterItemInfo *info,
+                          gpointer         user_data)
+{
+  gdm_lang_handler (user_data);
+}
+
 static void
 greeter_setup_items (void)
 {
@@ -642,12 +709,12 @@ verify_gdm_version (void)
                                 "Please restart the GDM daemon or the computer."),
                               VERSION);
     
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_OK,
-				  _("Cannot start the greeter"),
-				  msg);
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_ERROR,
+                               GTK_BUTTONS_OK,
+                               _("Cannot start the greeter"),
+                               msg);
       g_free (msg);
     
       gtk_widget_show_all (dialog);
@@ -677,12 +744,12 @@ verify_gdm_version (void)
                                "Please restart the GDM daemon or the computer."),
                              VERSION);
     
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_WARNING,
-				  GTK_BUTTONS_NONE,
-				  _("Cannot start the greeter"),
-				  msg);
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_WARNING,
+                               GTK_BUTTONS_NONE,
+                               _("Cannot start the greeter"),
+                               msg);
       g_free (msg);
 			  
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
@@ -726,12 +793,12 @@ verify_gdm_version (void)
                                "Please restart the GDM daemon or the computer."),
                              VERSION, gdm_version);
     
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_WARNING,
-				  GTK_BUTTONS_NONE,
-				  _("Cannot start the greeter"),
-				  msg);
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_WARNING,
+                               GTK_BUTTONS_NONE,
+                               _("Cannot start the greeter"),
+                               msg);
       g_free (msg);
 
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
@@ -796,8 +863,6 @@ gdm_read_config (void)
 	/* Read config data in bulk */
 	gdmcomm_comm_bulk_start ();
 
-	gdmcomm_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
-
 	/*
 	 * Read all the keys at once and close sockets connection so we do
 	 * not have to keep the socket open.
@@ -827,6 +892,9 @@ gdm_read_config (void)
 	gdm_config_get_string (GDM_KEY_USE_24_CLOCK);
 	gdm_config_get_string (GDM_KEY_WELCOME);
 	gdm_config_get_string (GDM_KEY_REMOTE_WELCOME);
+        gdm_config_get_string (GDM_KEY_RBAC_SYSTEM_COMMAND_KEYS);
+        gdm_config_get_string (GDM_KEY_SYSTEM_COMMANDS_IN_MENU);
+
 	gdm_config_get_int    (GDM_KEY_XINERAMA_SCREEN);
 	gdm_config_get_int    (GDM_KEY_TIMED_LOGIN_DELAY);
 	gdm_config_get_int    (GDM_KEY_FLEXI_REAP_DELAY_MINUTES);
@@ -850,23 +918,24 @@ gdm_read_config (void)
 	gdm_config_get_bool   (GDM_KEY_DEFAULT_WELCOME);
 	gdm_config_get_bool   (GDM_KEY_DEFAULT_REMOTE_WELCOME);
 	gdm_config_get_bool   (GDM_KEY_ADD_GTK_MODULES);
+	gdm_config_get_bool   (GDM_KEY_BROWSER);
 
 	/* Keys for custom commands */
 	for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {
 		gchar * key_string = NULL;
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
 		gdm_config_get_string (key_string);
 
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
 		gdm_config_get_string (key_string);
 		
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_LR_LABEL_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LR_LABEL_TEMPLATE, i);
 		gdm_config_get_string (key_string);
 		
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TEXT_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEXT_TEMPLATE, i);
 		gdm_config_get_string (key_string);
         
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TOOLTIP_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TOOLTIP_TEMPLATE, i);
 		gdm_config_get_string (key_string);
 
 		g_free (key_string);
@@ -888,9 +957,6 @@ greeter_reread_config (int sig, gpointer data)
 	/* Read config data in bulk */
 	gdmcomm_comm_bulk_start ();
 
-	if (gdm_config_reload_bool (GDM_KEY_DEBUG))
-		gdmcomm_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
-
 	/* FIXME: The following is evil, we should update on the fly rather
 	 * then just restarting */
 	/* Also we may not need to check ALL those keys but just a few */
@@ -914,12 +980,16 @@ greeter_reread_config (int sig, gpointer data)
 	    gdm_config_reload_string (GDM_KEY_BACKGROUND_COLOR) ||
 	    gdm_config_reload_string (GDM_KEY_DEFAULT_FACE) ||
 	    gdm_config_reload_string (GDM_KEY_DEFAULT_SESSION) ||
+            gdm_config_reload_string (GDM_KEY_RBAC_SYSTEM_COMMAND_KEYS) ||
+            gdm_config_reload_string (GDM_KEY_SYSTEM_COMMANDS_IN_MENU) ||
+
 	    gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
 	    gdm_config_reload_int    (GDM_KEY_TIMED_LOGIN_DELAY) ||
 	    gdm_config_reload_int    (GDM_KEY_FLEXI_REAP_DELAY_MINUTES) ||
 	    gdm_config_reload_int    (GDM_KEY_MAX_ICON_HEIGHT) ||
 	    gdm_config_reload_int    (GDM_KEY_MAX_ICON_WIDTH) ||
 	    gdm_config_reload_int    (GDM_KEY_MINIMAL_UID) ||
+
 	    gdm_config_reload_bool   (GDM_KEY_ENTRY_CIRCLES) ||
 	    gdm_config_reload_bool   (GDM_KEY_ENTRY_INVISIBLE) ||
 	    gdm_config_reload_bool   (GDM_KEY_SHOW_XTERM_FAILSAFE) ||
@@ -933,7 +1003,8 @@ greeter_reread_config (int sig, gpointer data)
 	    gdm_config_reload_bool   (GDM_KEY_SHOW_LAST_SESSION) ||
 	    gdm_config_reload_bool   (GDM_KEY_ALLOW_ROOT) ||
 	    gdm_config_reload_bool   (GDM_KEY_ALLOW_REMOTE_ROOT) ||
-	    gdm_config_reload_bool   (GDM_KEY_ADD_GTK_MODULES)) {
+	    gdm_config_reload_bool   (GDM_KEY_ADD_GTK_MODULES) ||
+	    gdm_config_reload_bool   (GDM_KEY_BROWSER)) {
 
 		/* Set busy cursor */
 		gdm_common_setup_cursor (GDK_WATCH);
@@ -946,23 +1017,23 @@ greeter_reread_config (int sig, gpointer data)
 
 	for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {
 		gchar *key_string = NULL;
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
 		
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
 		
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_LR_LABEL_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_LR_LABEL_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
 		
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TEXT_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEXT_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
 		
-		key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TOOLTIP_TEMPLATE, i);
+		key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TOOLTIP_TEMPLATE, i);
 		if (gdm_config_reload_string (key_string))
 			custom_changed = TRUE;
 
@@ -1154,7 +1225,6 @@ main (int argc, char *argv[])
   sigset_t mask;
   GIOChannel *ctrlch;
   GError *error;
-  GreeterItemInfo *root;
   char *theme_file;
   char *theme_dir;
   gchar *gdm_graphical_theme;
@@ -1166,8 +1236,6 @@ main (int argc, char *argv[])
   if (g_getenv ("DOING_GDM_DEVELOPMENT") != NULL)
     DOING_GDM_DEVELOPMENT = TRUE;
 
-  gdm_common_openlog ("gdmgreeter", LOG_PID, LOG_DAEMON);
-
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
@@ -1188,11 +1256,14 @@ main (int argc, char *argv[])
   if (! DOING_GDM_DEVELOPMENT) {
        gdm_common_atspi_launch ();
   }
-  
+
   gtk_init (&argc, &argv);
 
   gdm_common_setup_cursor (GDK_WATCH);
 
+  gdm_common_log_init ();
+  gdm_common_log_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
+
   /* Read all configuration at once, so the values get cached */
   gdm_read_config ();
 
@@ -1223,7 +1294,7 @@ main (int argc, char *argv[])
   }
   gdm_common_setup_background_color (bg_color);
   greeter_session_init ();
-  greeter_language_initialize_model ();
+  gdm_lang_initialize_model (gdm_config_get_string (GDM_KEY_LOCALE_FILE));
 
   ve_signal_add (SIGHUP, greeter_reread_config, NULL);
 
@@ -1303,7 +1374,7 @@ main (int argc, char *argv[])
   for (i = 0; i < GDM_CUSTOM_COMMAND_MAX; i++) {
 	  gchar * key_string = NULL;
 	  /*  For each possible custom command */      
-	  key_string = g_strdup_printf(_("%s%d="), GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
+	  key_string = g_strdup_printf("%s%d=", GDM_KEY_CUSTOM_CMD_TEMPLATE, i);
 	  GdmCustomCmdsFound[i] = gdm_working_command_exists (gdm_config_get_string (key_string));
 	  if (GdmCustomCmdsFound[i])
 		  GdmAnyCustomCmdsFound = TRUE;
@@ -1340,12 +1411,12 @@ main (int argc, char *argv[])
 	s = g_strdup_printf (_("There was an error loading the "
 			       "theme %s"), tmp);
 	g_free (tmp);
-        dialog = ve_hig_dialog_new (NULL /* parent */,
-				    GTK_DIALOG_MODAL /* flags */,
-				    GTK_MESSAGE_ERROR,
-				    GTK_BUTTONS_OK,
-				    s,
-				    (error && error->message) ? error->message : "");
+        dialog = hig_dialog_new (NULL /* parent */,
+                                 GTK_DIALOG_MODAL /* flags */,
+                                 GTK_MESSAGE_ERROR,
+                                 GTK_BUTTONS_OK,
+                                 s,
+                                 (error && error->message) ? error->message : "");
 	g_free (s);
     
         gtk_widget_show_all (dialog);
@@ -1387,14 +1458,14 @@ main (int argc, char *argv[])
       gdm_wm_init (0);
       gdm_wm_focus_new_windows (TRUE);
     
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_OK,
-				  _("The greeter theme is corrupt"),
-				  _("The theme does not contain "
-				    "definition for the username/password "
-				    "entry element."));
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_ERROR,
+                               GTK_BUTTONS_OK,
+                               _("The greeter theme is corrupt"),
+                               _("The theme does not contain "
+                                 "definition for the username/password "
+                                 "entry element."));
 
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
@@ -1421,16 +1492,16 @@ main (int argc, char *argv[])
       gdm_wm_init (0);
       gdm_wm_focus_new_windows (TRUE);
     
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_OK,
-				  _("There was an error loading the "
-				    "theme, and the default theme "
-				    "could not be loaded. "
-				    "Attempting to start the "
-				    "standard greeter"),
-				  "");
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_ERROR,
+                               GTK_BUTTONS_OK,
+                               _("There was an error loading the "
+                                 "theme, and the default theme "
+                                 "could not be loaded. "
+                                 "Attempting to start the "
+                                 "standard greeter"),
+                               "");
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
@@ -1443,15 +1514,15 @@ main (int argc, char *argv[])
       execl (LIBEXECDIR "/gdmlogin", LIBEXECDIR "/gdmlogin", NULL);
       execlp ("gdmlogin", "gdmlogin", NULL);
 
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_OK,
-				  _("The GTK+ greeter could not be started.  "
-				    "This display will abort and you may "
-				    "have to login another way and fix the "
-				    "installation of GDM"),
-				  "");
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_ERROR,
+                               GTK_BUTTONS_OK,
+                               _("The GTK+ greeter could not be started.  "
+                                 "This display will abort and you may "
+                                 "have to login another way and fix the "
+                                 "installation of GDM"),
+                               "");
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
@@ -1509,14 +1580,14 @@ main (int argc, char *argv[])
 
       gdm_wm_focus_new_windows (TRUE);
 
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_OK,
-				  _("Session directory is missing"),
-				  _("Your session directory is missing or empty!  "
-				    "There are two available sessions you can use, but "
-				    "you should log in and correct the gdm configuration."));
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_ERROR,
+                               GTK_BUTTONS_OK,
+                               _("Session directory is missing"),
+                               _("Your session directory is missing or empty!  "
+                                 "There are two available sessions you can use, but "
+                                 "you should log in and correct the gdm configuration."));
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
 
@@ -1534,14 +1605,14 @@ main (int argc, char *argv[])
 
       gdm_wm_focus_new_windows (TRUE);
 
-      dialog = ve_hig_dialog_new (NULL /* parent */,
-				  GTK_DIALOG_MODAL /* flags */,
-				  GTK_MESSAGE_ERROR,
-				  GTK_BUTTONS_OK,
-				  _("Configuration is not correct"),
-				  _("The configuration file contains an invalid command "
-				    "line for the login dialog, so running the "
-				    "default command.  Please fix your configuration."));
+      dialog = hig_dialog_new (NULL /* parent */,
+                               GTK_DIALOG_MODAL /* flags */,
+                               GTK_MESSAGE_ERROR,
+                               GTK_BUTTONS_OK,
+                               _("Configuration is not correct"),
+                               _("The configuration file contains an invalid command "
+                                 "line for the login dialog, so running the "
+                                 "default command.  Please fix your configuration."));
 
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
