@@ -23,6 +23,6 @@
 
 gboolean greeter_item_customlist_setup (void);
 void     greeter_custom_set_session    (gchar *session);
-void     greeter_custom_set_language   (gchar *language);
+void     lang_set_custom_callback      (gchar *language);
 
 #endif
