@@ -24,13 +24,18 @@
 #include <stdlib.h>
 #include <librsvg/rsvg.h>
 #include <math.h>
-#include <gdk/gdkx.h>
 #include <locale.h>
 #include <glib/gi18n.h>
+#include <gdk/gdkx.h>
+#include <syslog.h>
 
 #include "gdmwm.h"
 #include "gdmcommon.h"
 #include "gdmconfig.h"
+
+#include "gdm-common.h"
+#include "gdm-daemon-config-keys.h"
+
 #include "greeter_configuration.h"
 #include "greeter_parser.h"
 #include "greeter_events.h"
@@ -416,11 +421,11 @@ parse_stock (xmlNodePtr node,
 	  register int i = 0;
 	    for (; i < GDM_CUSTOM_COMMAND_MAX; i++) {
 		gchar * key_string = NULL;
-		key_string = g_strdup_printf (_("custom_cmd%d"), i);
+		key_string = g_strdup_printf ("custom_cmd%d", i);
 		if (g_ascii_strcasecmp ((char *) prop, key_string) == 0) {
 		    g_free (*translated_text);
 		    g_free (key_string);
-		    key_string = g_strdup_printf (_("%s%d="), GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
+		    key_string = g_strdup_printf ("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
 		    *translated_text = g_strdup(gdm_config_get_string (key_string));
 		    g_free (key_string);
 		    is_error = FALSE;
@@ -597,7 +602,23 @@ parse_show (xmlNodePtr       node,
       }
       xmlFree (prop);
     }
-  
+
+  prop = xmlGetProp (node,(const xmlChar *) "min-screen-width");
+  if (prop != NULL)
+    {
+          g_warning ("minimum width is %d", info->minimum_required_screen_height);
+	  info->minimum_required_screen_width = atoi ((char *) prop);
+	  xmlFree (prop);
+    }
+
+  prop = xmlGetProp (node,(const xmlChar *) "min-screen-height");
+  if (prop != NULL)
+    {
+	  info->minimum_required_screen_height = atoi ((char *) prop);
+          g_warning ("minimum height is %d", info->minimum_required_screen_height);
+	  xmlFree (prop);
+    }
+
   prop = xmlGetProp (node,(const xmlChar *) "modes");
   if (prop != NULL)
     {
@@ -1238,15 +1259,17 @@ parse_state_text (xmlNodePtr node,
 static gint
 is_current_locale (const char *lang)
 {
-  const GList *l = ve_i18n_get_language_list ("LC_MESSAGES");
+  const char * const *langs;
   int score = 0;
-  
-  while (l != NULL)
+  int i;
+
+  langs = g_get_language_names ();
+
+  for (i = 0; langs[i] != NULL; i++)
     {
-      if (strcmp (l->data, lang) == 0)
+      if (strcmp (langs[i], lang) == 0)
 	return score;
 
-      l = l->next;
       score++;
     }
   return 1000;
@@ -1642,6 +1665,7 @@ parse_items (xmlNodePtr  node,
     GList *items;
     gboolean res;
     xmlChar *type;
+    xmlChar *background;
     GreeterItemInfo *info;
     GreeterItemType item_type;
 
@@ -1743,6 +1767,20 @@ parse_items (xmlNodePtr  node,
 
 	    if (info->canvasbutton)
 	      button_stack = g_list_remove (button_stack, info);
+
+	    background = xmlGetProp (child, (const xmlChar *) "background");
+	    if G_UNLIKELY (background)
+	      {
+		if (strcmp ((char *) background, "true") == 0)
+		   {
+		      info->background = TRUE;
+		   }
+		else if (strcmp ((char *) background, "false") == 0)
+		   {
+		      info->background = FALSE;
+		   }
+		xmlFree (background);
+	      }
 	    
 	    if G_UNLIKELY (!res)
 	      return FALSE;
@@ -1909,3 +1947,51 @@ greeter_custom_items (void)
 {
   return custom_items;
 }
+
+static void
+hide_item (GreeterItemInfo *info, gpointer user_data)
+{  
+	GnomeCanvasItem *item;
+	gboolean *found_background;
+
+	found_background = user_data;
+
+	if (info)
+       	{
+	     if (info->background)
+	     {
+		     *found_background = TRUE;
+	     }
+	     else {
+		item = info->item;
+	      	if (item) {
+			if (GNOME_IS_CANVAS_WIDGET (item)) {
+				gtk_widget_hide (GNOME_CANVAS_WIDGET (item)->widget);
+			}
+			else
+			gnome_canvas_item_hide (item);
+		}
+		if ((info->item_type == GREETER_ITEM_TYPE_ENTRY) &&
+			(info->data.text.menubar != NULL)) {
+				gtk_widget_hide (info->data.text.menubar);
+			}
+	     }
+
+	g_list_foreach (info->fixed_children, (GFunc) hide_item, user_data);
+	g_list_foreach (info->box_children, (GFunc) hide_item, user_data);
+      }
+}
+
+gboolean 
+greeter_show_only_background (GreeterItemInfo *root_item)
+{
+	gboolean found_background = FALSE;
+
+	hide_item (root_item, &found_background);
+
+	/* ensure root canvas is updated */
+	while (gtk_events_pending ())
+	  gtk_main_iteration ();
+
+	return found_background;
+}
